Class: Aws::MigrationHubStrategyRecommendations::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubStrategyRecommendations::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhubstrategyrecommendations/client.rb,
sig/client.rbs
Overview
An API client for MigrationHubStrategyRecommendations. To construct a client, you need to configure a :region and :credentials.
client = Aws::MigrationHubStrategyRecommendations::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetApplicationComponentDetailsResponseSuccess, _GetApplicationComponentStrategiesResponseSuccess, _GetAssessmentResponseSuccess, _GetImportFileTaskResponseSuccess, _GetLatestAssessmentIdResponseSuccess, _GetPortfolioPreferencesResponseSuccess, _GetPortfolioSummaryResponseSuccess, _GetRecommendationReportDetailsResponseSuccess, _GetServerDetailsResponseSuccess, _GetServerStrategiesResponseSuccess, _ListAnalyzableServersResponseSuccess, _ListApplicationComponentsResponseSuccess, _ListCollectorsResponseSuccess, _ListImportFileTaskResponseSuccess, _ListServersResponseSuccess, _PutPortfolioPreferencesResponseSuccess, _StartAssessmentResponseSuccess, _StartImportFileTaskResponseSuccess, _StartRecommendationReportGenerationResponseSuccess, _StopAssessmentResponseSuccess, _UpdateApplicationComponentConfigResponseSuccess, _UpdateServerConfigResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_application_component_details(params = {}) ⇒ Types::GetApplicationComponentDetailsResponse
Retrieves details about an application component.
-
#get_application_component_strategies(params = {}) ⇒ Types::GetApplicationComponentStrategiesResponse
Retrieves a list of all the recommended strategies and tools for an application component running on a server.
-
#get_assessment(params = {}) ⇒ Types::GetAssessmentResponse
Retrieves the status of an on-going assessment.
-
#get_import_file_task(params = {}) ⇒ Types::GetImportFileTaskResponse
Retrieves the details about a specific import task.
-
#get_latest_assessment_id(params = {}) ⇒ Types::GetLatestAssessmentIdResponse
Retrieve the latest ID of a specific assessment task.
-
#get_portfolio_preferences(params = {}) ⇒ Types::GetPortfolioPreferencesResponse
Retrieves your migration and modernization preferences.
-
#get_portfolio_summary(params = {}) ⇒ Types::GetPortfolioSummaryResponse
Retrieves overall summary including the number of servers to rehost and the overall number of anti-patterns.
-
#get_recommendation_report_details(params = {}) ⇒ Types::GetRecommendationReportDetailsResponse
Retrieves detailed information about the specified recommendation report.
-
#get_server_details(params = {}) ⇒ Types::GetServerDetailsResponse
Retrieves detailed information about a specified server.
-
#get_server_strategies(params = {}) ⇒ Types::GetServerStrategiesResponse
Retrieves recommended strategies and tools for the specified server.
-
#list_analyzable_servers(params = {}) ⇒ Types::ListAnalyzableServersResponse
Retrieves a list of all the servers fetched from customer vCenter using Strategy Recommendation Collector.
-
#list_application_components(params = {}) ⇒ Types::ListApplicationComponentsResponse
Retrieves a list of all the application components (processes).
-
#list_collectors(params = {}) ⇒ Types::ListCollectorsResponse
Retrieves a list of all the installed collectors.
-
#list_import_file_task(params = {}) ⇒ Types::ListImportFileTaskResponse
Retrieves a list of all the imports performed.
-
#list_servers(params = {}) ⇒ Types::ListServersResponse
Returns a list of all the servers.
-
#put_portfolio_preferences(params = {}) ⇒ Struct
Saves the specified migration and modernization preferences.
-
#start_assessment(params = {}) ⇒ Types::StartAssessmentResponse
Starts the assessment of an on-premises environment.
-
#start_import_file_task(params = {}) ⇒ Types::StartImportFileTaskResponse
Starts a file import.
-
#start_recommendation_report_generation(params = {}) ⇒ Types::StartRecommendationReportGenerationResponse
Starts generating a recommendation report.
-
#stop_assessment(params = {}) ⇒ Struct
Stops the assessment of an on-premises environment.
-
#update_application_component_config(params = {}) ⇒ Struct
Updates the configuration of an application component.
-
#update_server_config(params = {}) ⇒ Struct
Updates the configuration of the specified server.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1679 1680 1681 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1679 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1682 1683 1684 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1682 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1652 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubStrategyRecommendations') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhubstrategyrecommendations' context[:gem_version] = '1.56.0' Seahorse::Client::Request.new(handlers, context) end |
#get_application_component_details(params = {}) ⇒ Types::GetApplicationComponentDetailsResponse
Retrieves details about an application component.
89 |
# File 'sig/client.rbs', line 89
def get_application_component_details: (
|
#get_application_component_strategies(params = {}) ⇒ Types::GetApplicationComponentStrategiesResponse
Retrieves a list of all the recommended strategies and tools for an application component running on a server.
99 |
# File 'sig/client.rbs', line 99
def get_application_component_strategies: (
|
#get_assessment(params = {}) ⇒ Types::GetAssessmentResponse
Retrieves the status of an on-going assessment.
111 |
# File 'sig/client.rbs', line 111
def get_assessment: (
|
#get_import_file_task(params = {}) ⇒ Types::GetImportFileTaskResponse
Retrieves the details about a specific import task.
131 |
# File 'sig/client.rbs', line 131
def get_import_file_task: (
|
#get_latest_assessment_id(params = {}) ⇒ Types::GetLatestAssessmentIdResponse
Retrieve the latest ID of a specific assessment task.
141 |
# File 'sig/client.rbs', line 141
def get_latest_assessment_id: (
|
#get_portfolio_preferences(params = {}) ⇒ Types::GetPortfolioPreferencesResponse
Retrieves your migration and modernization preferences.
153 |
# File 'sig/client.rbs', line 153
def get_portfolio_preferences: (
|
#get_portfolio_summary(params = {}) ⇒ Types::GetPortfolioSummaryResponse
Retrieves overall summary including the number of servers to rehost and the overall number of anti-patterns.
162 |
# File 'sig/client.rbs', line 162
def get_portfolio_summary: (
|
#get_recommendation_report_details(params = {}) ⇒ Types::GetRecommendationReportDetailsResponse
Retrieves detailed information about the specified recommendation report.
172 |
# File 'sig/client.rbs', line 172
def get_recommendation_report_details: (
|
#get_server_details(params = {}) ⇒ Types::GetServerDetailsResponse
Retrieves detailed information about a specified server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
184 |
# File 'sig/client.rbs', line 184
def get_server_details: (
|
#get_server_strategies(params = {}) ⇒ Types::GetServerStrategiesResponse
Retrieves recommended strategies and tools for the specified server.
196 |
# File 'sig/client.rbs', line 196
def get_server_strategies: (
|
#list_analyzable_servers(params = {}) ⇒ Types::ListAnalyzableServersResponse
Retrieves a list of all the servers fetched from customer vCenter using Strategy Recommendation Collector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
207 |
# File 'sig/client.rbs', line 207
def list_analyzable_servers: (
|
#list_application_components(params = {}) ⇒ Types::ListApplicationComponentsResponse
Retrieves a list of all the application components (processes).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
220 |
# File 'sig/client.rbs', line 220
def list_application_components: (
|
#list_collectors(params = {}) ⇒ Types::ListCollectorsResponse
Retrieves a list of all the installed collectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
241 |
# File 'sig/client.rbs', line 241
def list_collectors: (
|
#list_import_file_task(params = {}) ⇒ Types::ListImportFileTaskResponse
Retrieves a list of all the imports performed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
253 |
# File 'sig/client.rbs', line 253
def list_import_file_task: (
|
#list_servers(params = {}) ⇒ Types::ListServersResponse
Returns a list of all the servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
265 |
# File 'sig/client.rbs', line 265
def list_servers: (
|
#put_portfolio_preferences(params = {}) ⇒ Struct
Saves the specified migration and modernization preferences.
284 |
# File 'sig/client.rbs', line 284
def put_portfolio_preferences: (
|
#start_assessment(params = {}) ⇒ Types::StartAssessmentResponse
Starts the assessment of an on-premises environment.
329 |
# File 'sig/client.rbs', line 329
def start_assessment: (
|
#start_import_file_task(params = {}) ⇒ Types::StartImportFileTaskResponse
Starts a file import.
348 |
# File 'sig/client.rbs', line 348
def start_import_file_task: (
|
#start_recommendation_report_generation(params = {}) ⇒ Types::StartRecommendationReportGenerationResponse
Starts generating a recommendation report.
368 |
# File 'sig/client.rbs', line 368
def start_recommendation_report_generation: (
|
#stop_assessment(params = {}) ⇒ Struct
Stops the assessment of an on-premises environment.
383 |
# File 'sig/client.rbs', line 383
def stop_assessment: (
|
#update_application_component_config(params = {}) ⇒ Struct
Updates the configuration of an application component.
392 |
# File 'sig/client.rbs', line 392
def update_application_component_config: (
|
#update_server_config(params = {}) ⇒ Struct
Updates the configuration of the specified server.
419 |
# File 'sig/client.rbs', line 419
def update_server_config: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1672 1673 1674 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1672 def waiter_names [] end |