Method: Aws::MigrationHubStrategyRecommendations::Client#list_application_components

Defined in:
lib/aws-sdk-migrationhubstrategyrecommendations/client.rb

#list_application_components(params = {}) ⇒ Types::ListApplicationComponentsResponse

Retrieves a list of all the application components (processes).

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_application_components({
  application_component_criteria: "NOT_DEFINED", # accepts NOT_DEFINED, APP_NAME, SERVER_ID, APP_TYPE, STRATEGY, DESTINATION, ANALYSIS_STATUS, ERROR_CATEGORY
  filter_value: "ListApplicationComponentsRequestFilterValueString",
  group_id_filter: [
    {
      name: "ExternalId", # accepts ExternalId, ExternalSourceType
      value: "String",
    },
  ],
  max_results: 1,
  next_token: "NextToken",
  sort: "ASC", # accepts ASC, DESC
})

Response structure


resp.application_component_infos #=> Array
resp.application_component_infos[0].analysis_status #=> String, one of "ANALYSIS_TO_BE_SCHEDULED", "ANALYSIS_STARTED", "ANALYSIS_SUCCESS", "ANALYSIS_FAILED", "ANALYSIS_PARTIAL_SUCCESS", "UNCONFIGURED", "CONFIGURED"
resp.application_component_infos[0].antipattern_report_s3_object.s3_bucket #=> String
resp.application_component_infos[0].antipattern_report_s3_object.s3key #=> String
resp.application_component_infos[0].antipattern_report_status #=> String, one of "FAILED", "IN_PROGRESS", "SUCCESS"
resp.application_component_infos[0].antipattern_report_status_message #=> String
resp.application_component_infos[0].app_type #=> String, one of "DotNetFramework", "Java", "SQLServer", "IIS", "Oracle", "Other", "Tomcat", "JBoss", "Spring", "Mongo DB", "DB2", "Maria DB", "MySQL", "Sybase", "PostgreSQLServer", "Cassandra", "IBM WebSphere", "Oracle WebLogic", "Visual Basic", "Unknown", "DotnetCore", "Dotnet"
resp.application_component_infos[0].app_unit_error.app_unit_error_category #=> String, one of "CREDENTIAL_ERROR", "CONNECTIVITY_ERROR", "PERMISSION_ERROR", "UNSUPPORTED_ERROR", "OTHER_ERROR"
resp.application_component_infos[0].associated_server_id #=> String
resp.application_component_infos[0].database_config_detail.secret_name #=> String
resp.application_component_infos[0].id #=> String
resp.application_component_infos[0].inclusion_status #=> String, one of "excludeFromAssessment", "includeInAssessment"
resp.application_component_infos[0].last_analyzed_timestamp #=> Time
resp.application_component_infos[0].list_antipattern_severity_summary #=> Array
resp.application_component_infos[0].list_antipattern_severity_summary[0].count #=> Integer
resp.application_component_infos[0].list_antipattern_severity_summary[0].severity #=> String, one of "HIGH", "MEDIUM", "LOW"
resp.application_component_infos[0].more_server_association_exists #=> Boolean
resp.application_component_infos[0].name #=> String
resp.application_component_infos[0].os_driver #=> String
resp.application_component_infos[0].os_version #=> String
resp.application_component_infos[0].recommendation_set.strategy #=> String, one of "Rehost", "Retirement", "Refactor", "Replatform", "Retain", "Relocate", "Repurchase"
resp.application_component_infos[0].recommendation_set.target_destination #=> String, one of "None specified", "AWS Elastic BeanStalk", "AWS Fargate", "Amazon Elastic Cloud Compute (EC2)", "Amazon Elastic Container Service (ECS)", "Amazon Elastic Kubernetes Service (EKS)", "Aurora MySQL", "Aurora PostgreSQL", "Amazon Relational Database Service on MySQL", "Amazon Relational Database Service on PostgreSQL", "Amazon DocumentDB", "Amazon DynamoDB", "Amazon Relational Database Service", "Babelfish for Aurora PostgreSQL"
resp.application_component_infos[0].recommendation_set.transformation_tool.description #=> String
resp.application_component_infos[0].recommendation_set.transformation_tool.name #=> String, one of "App2Container", "Porting Assistant For .NET", "End of Support Migration", "Windows Web Application Migration Assistant", "Application Migration Service", "Strategy Recommendation Support", "In Place Operating System Upgrade", "Schema Conversion Tool", "Database Migration Service", "Native SQL Server Backup/Restore"
resp.application_component_infos[0].recommendation_set.transformation_tool.tranformation_tool_installation_link #=> String
resp.application_component_infos[0].resource_sub_type #=> String, one of "Database", "Process", "DatabaseProcess"
resp.application_component_infos[0].result_list #=> Array
resp.application_component_infos[0].result_list[0].analysis_status.runtime_analysis_status #=> String, one of "ANALYSIS_TO_BE_SCHEDULED", "ANALYSIS_STARTED", "ANALYSIS_SUCCESS", "ANALYSIS_FAILED"
resp.application_component_infos[0].result_list[0].analysis_status.src_code_or_db_analysis_status #=> String, one of "ANALYSIS_TO_BE_SCHEDULED", "ANALYSIS_STARTED", "ANALYSIS_SUCCESS", "ANALYSIS_FAILED", "ANALYSIS_PARTIAL_SUCCESS", "UNCONFIGURED", "CONFIGURED"
resp.application_component_infos[0].result_list[0].analysis_type #=> String, one of "SOURCE_CODE_ANALYSIS", "DATABASE_ANALYSIS", "RUNTIME_ANALYSIS", "BINARY_ANALYSIS"
resp.application_component_infos[0].result_list[0].antipattern_report_result_list #=> Array
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].analyzer_name.binary_analyzer_name #=> String, one of "DLL_ANALYZER", "BYTECODE_ANALYZER"
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].analyzer_name.run_time_analyzer_name #=> String, one of "A2C_ANALYZER", "REHOST_ANALYZER", "EMP_PA_ANALYZER", "DATABASE_ANALYZER", "SCT_ANALYZER"
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].analyzer_name.source_code_analyzer_name #=> String, one of "CSHARP_ANALYZER", "JAVA_ANALYZER", "BYTECODE_ANALYZER", "PORTING_ASSISTANT"
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].anti_pattern_report_s3_object.s3_bucket #=> String
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].anti_pattern_report_s3_object.s3key #=> String
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].antipattern_report_status #=> String, one of "FAILED", "IN_PROGRESS", "SUCCESS"
resp.application_component_infos[0].result_list[0].antipattern_report_result_list[0].antipattern_report_status_message #=> String
resp.application_component_infos[0].result_list[0].status_message #=> String
resp.application_component_infos[0].runtime_status #=> String, one of "ANALYSIS_TO_BE_SCHEDULED", "ANALYSIS_STARTED", "ANALYSIS_SUCCESS", "ANALYSIS_FAILED"
resp.application_component_infos[0].runtime_status_message #=> String
resp.application_component_infos[0].source_code_repositories #=> Array
resp.application_component_infos[0].source_code_repositories[0].branch #=> String
resp.application_component_infos[0].source_code_repositories[0].project_name #=> String
resp.application_component_infos[0].source_code_repositories[0].repository #=> String
resp.application_component_infos[0].source_code_repositories[0].version_control_type #=> String
resp.application_component_infos[0].status_message #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :application_component_criteria (String)

    Criteria for filtering the list of application components.

  • :filter_value (String)

    Specify the value based on the application component criteria type. For example, if applicationComponentCriteria is set to SERVER_ID and filterValue is set to server1, then ListApplicationComponents returns all the application components running on server1.

  • :group_id_filter (Array<Types::Group>)

    The group ID specified in to filter on.

  • :max_results (Integer)

    The maximum number of items to include in the response. The maximum value is 100.

  • :next_token (String)

    The token from a previous call that you use to retrieve the next set of results. For example, if a previous call to this action returned 100 items, but you set maxResults to 10. You’ll receive a set of 10 results along with a token. You then use the returned token to retrieve the next set of 10.

  • :sort (String)

    Specifies whether to sort by ascending (ASC) or descending (DESC) order.

Returns:

See Also:



1105
1106
1107
1108
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1105

def list_application_components(params = {}, options = {})
  req = build_request(:list_application_components, params)
  req.send_request(options)
end