Class: Aws::MigrationHubStrategyRecommendations::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubStrategyRecommendations::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhubstrategyrecommendations/client.rb
Overview
An API client for MigrationHubStrategyRecommendations. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MigrationHubStrategyRecommendations::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_application_component_details(params = {}) ⇒ Types::GetApplicationComponentDetailsResponse
Retrieves details about an application component.
-
#get_application_component_strategies(params = {}) ⇒ Types::GetApplicationComponentStrategiesResponse
Retrieves a list of all the recommended strategies and tools for an application component running on a server.
-
#get_assessment(params = {}) ⇒ Types::GetAssessmentResponse
Retrieves the status of an on-going assessment.
-
#get_import_file_task(params = {}) ⇒ Types::GetImportFileTaskResponse
Retrieves the details about a specific import task.
-
#get_latest_assessment_id(params = {}) ⇒ Types::GetLatestAssessmentIdResponse
Retrieve the latest ID of a specific assessment task.
-
#get_portfolio_preferences(params = {}) ⇒ Types::GetPortfolioPreferencesResponse
Retrieves your migration and modernization preferences.
-
#get_portfolio_summary(params = {}) ⇒ Types::GetPortfolioSummaryResponse
Retrieves overall summary including the number of servers to rehost and the overall number of anti-patterns.
-
#get_recommendation_report_details(params = {}) ⇒ Types::GetRecommendationReportDetailsResponse
Retrieves detailed information about the specified recommendation report.
-
#get_server_details(params = {}) ⇒ Types::GetServerDetailsResponse
Retrieves detailed information about a specified server.
-
#get_server_strategies(params = {}) ⇒ Types::GetServerStrategiesResponse
Retrieves recommended strategies and tools for the specified server.
-
#list_analyzable_servers(params = {}) ⇒ Types::ListAnalyzableServersResponse
Retrieves a list of all the servers fetched from customer vCenter using Strategy Recommendation Collector.
-
#list_application_components(params = {}) ⇒ Types::ListApplicationComponentsResponse
Retrieves a list of all the application components (processes).
-
#list_collectors(params = {}) ⇒ Types::ListCollectorsResponse
Retrieves a list of all the installed collectors.
-
#list_import_file_task(params = {}) ⇒ Types::ListImportFileTaskResponse
Retrieves a list of all the imports performed.
-
#list_servers(params = {}) ⇒ Types::ListServersResponse
Returns a list of all the servers.
-
#put_portfolio_preferences(params = {}) ⇒ Struct
Saves the specified migration and modernization preferences.
-
#start_assessment(params = {}) ⇒ Types::StartAssessmentResponse
Starts the assessment of an on-premises environment.
-
#start_import_file_task(params = {}) ⇒ Types::StartImportFileTaskResponse
Starts a file import.
-
#start_recommendation_report_generation(params = {}) ⇒ Types::StartRecommendationReportGenerationResponse
Starts generating a recommendation report.
-
#stop_assessment(params = {}) ⇒ Struct
Stops the assessment of an on-premises environment.
-
#update_application_component_config(params = {}) ⇒ Struct
Updates the configuration of an application component.
-
#update_server_config(params = {}) ⇒ Struct
Updates the configuration of the specified server.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1679 1680 1681 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1679 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1682 1683 1684 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1682 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1652 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubStrategyRecommendations') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhubstrategyrecommendations' context[:gem_version] = '1.54.0' Seahorse::Client::Request.new(handlers, context) end |
#get_application_component_details(params = {}) ⇒ Types::GetApplicationComponentDetailsResponse
Retrieves details about an application component.
555 556 557 558 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 555 def get_application_component_details(params = {}, = {}) req = build_request(:get_application_component_details, params) req.send_request() end |
#get_application_component_strategies(params = {}) ⇒ Types::GetApplicationComponentStrategiesResponse
Retrieves a list of all the recommended strategies and tools for an application component running on a server.
592 593 594 595 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 592 def get_application_component_strategies(params = {}, = {}) req = build_request(:get_application_component_strategies, params) req.send_request() end |
#get_assessment(params = {}) ⇒ Types::GetAssessmentResponse
Retrieves the status of an on-going assessment.
635 636 637 638 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 635 def get_assessment(params = {}, = {}) req = build_request(:get_assessment, params) req.send_request() end |
#get_import_file_task(params = {}) ⇒ Types::GetImportFileTaskResponse
Retrieves the details about a specific import task.
684 685 686 687 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 684 def get_import_file_task(params = {}, = {}) req = build_request(:get_import_file_task, params) req.send_request() end |
#get_latest_assessment_id(params = {}) ⇒ Types::GetLatestAssessmentIdResponse
Retrieve the latest ID of a specific assessment task.
703 704 705 706 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 703 def get_latest_assessment_id(params = {}, = {}) req = build_request(:get_latest_assessment_id, params) req.send_request() end |
#get_portfolio_preferences(params = {}) ⇒ Types::GetPortfolioPreferencesResponse
Retrieves your migration and modernization preferences.
742 743 744 745 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 742 def get_portfolio_preferences(params = {}, = {}) req = build_request(:get_portfolio_preferences, params) req.send_request() end |
#get_portfolio_summary(params = {}) ⇒ Types::GetPortfolioSummaryResponse
Retrieves overall summary including the number of servers to rehost and the overall number of anti-patterns.
787 788 789 790 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 787 def get_portfolio_summary(params = {}, = {}) req = build_request(:get_portfolio_summary, params) req.send_request() end |
#get_recommendation_report_details(params = {}) ⇒ Types::GetRecommendationReportDetailsResponse
Retrieves detailed information about the specified recommendation report.
825 826 827 828 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 825 def get_recommendation_report_details(params = {}, = {}) req = build_request(:get_recommendation_report_details, params) req.send_request() end |
#get_server_details(params = {}) ⇒ Types::GetServerDetailsResponse
Retrieves detailed information about a specified server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
904 905 906 907 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 904 def get_server_details(params = {}, = {}) req = build_request(:get_server_details, params) req.send_request() end |
#get_server_strategies(params = {}) ⇒ Types::GetServerStrategiesResponse
Retrieves recommended strategies and tools for the specified server.
940 941 942 943 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 940 def get_server_strategies(params = {}, = {}) req = build_request(:get_server_strategies, params) req.send_request() end |
#list_analyzable_servers(params = {}) ⇒ Types::ListAnalyzableServersResponse
Retrieves a list of all the servers fetched from customer vCenter using Strategy Recommendation Collector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
991 992 993 994 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 991 def list_analyzable_servers(params = {}, = {}) req = build_request(:list_analyzable_servers, params) req.send_request() end |
#list_application_components(params = {}) ⇒ Types::ListApplicationComponentsResponse
Retrieves a list of all the application components (processes).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1103 def list_application_components(params = {}, = {}) req = build_request(:list_application_components, params) req.send_request() end |
#list_collectors(params = {}) ⇒ Types::ListCollectorsResponse
Retrieves a list of all the installed collectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1165 1166 1167 1168 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1165 def list_collectors(params = {}, = {}) req = build_request(:list_collectors, params) req.send_request() end |
#list_import_file_task(params = {}) ⇒ Types::ListImportFileTaskResponse
Retrieves a list of all the imports performed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1216 1217 1218 1219 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1216 def list_import_file_task(params = {}, = {}) req = build_request(:list_import_file_task, params) req.send_request() end |
#list_servers(params = {}) ⇒ Types::ListServersResponse
Returns a list of all the servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1313 1314 1315 1316 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1313 def list_servers(params = {}, = {}) req = build_request(:list_servers, params) req.send_request() end |
#put_portfolio_preferences(params = {}) ⇒ Struct
Saves the specified migration and modernization preferences.
1379 1380 1381 1382 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1379 def put_portfolio_preferences(params = {}, = {}) req = build_request(:put_portfolio_preferences, params) req.send_request() end |
#start_assessment(params = {}) ⇒ Types::StartAssessmentResponse
Starts the assessment of an on-premises environment.
1427 1428 1429 1430 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1427 def start_assessment(params = {}, = {}) req = build_request(:start_assessment, params) req.send_request() end |
#start_import_file_task(params = {}) ⇒ Types::StartImportFileTaskResponse
Starts a file import.
1486 1487 1488 1489 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1486 def start_import_file_task(params = {}, = {}) req = build_request(:start_import_file_task, params) req.send_request() end |
#start_recommendation_report_generation(params = {}) ⇒ Types::StartRecommendationReportGenerationResponse
Starts generating a recommendation report.
1524 1525 1526 1527 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1524 def start_recommendation_report_generation(params = {}, = {}) req = build_request(:start_recommendation_report_generation, params) req.send_request() end |
#stop_assessment(params = {}) ⇒ Struct
Stops the assessment of an on-premises environment.
1546 1547 1548 1549 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1546 def stop_assessment(params = {}, = {}) req = build_request(:stop_assessment, params) req.send_request() end |
#update_application_component_config(params = {}) ⇒ Struct
Updates the configuration of an application component.
1611 1612 1613 1614 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1611 def update_application_component_config(params = {}, = {}) req = build_request(:update_application_component_config, params) req.send_request() end |
#update_server_config(params = {}) ⇒ Struct
Updates the configuration of the specified server.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1643 def update_server_config(params = {}, = {}) req = build_request(:update_server_config, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1672 1673 1674 |
# File 'lib/aws-sdk-migrationhubstrategyrecommendations/client.rb', line 1672 def waiter_names [] end |